==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GeographicProportionalSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var GeographicProportionalSymbolSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicProportionalSymbolSeriesBaseDescriptionMetadata, _super);
    function GeographicProportionalSymbolSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a == null) {
            GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicProportionalSymbolSeriesBaseDescriptionMetadata.c(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
        }
        if (a.g(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
    };
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicProportionalSymbolSeriesBaseDescriptionMetadata.b(a);
        a.t("GeographicProportionalSymbolSeriesBase", GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicProportionalSymbolSeriesBaseDescriptionMetadata, 'GeographicProportionalSymbolSeriesBaseDescriptionMetadata');
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicProportionalSymbolSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicProportionalSymbolSeriesBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicProportionalSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var GeographicProportionalSymbolSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicProportionalSymbolSeriesBaseDescriptionMetadata, _super);
    function GeographicProportionalSymbolSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a == null) {
            GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicProportionalSymbolSeriesBaseDescriptionMetadata.c(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
    };
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicProportionalSymbolSeriesBaseDescriptionMetadata.b(a);
        a.z("GeographicProportionalSymbolSeriesBase", GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicProportionalSymbolSeriesBaseDescriptionMetadata, 'GeographicProportionalSymbolSeriesBaseDescriptionMetadata');
    GeographicProportionalSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicProportionalSymbolSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicProportionalSymbolSeriesBaseDescriptionMetadata };
